==> tuia-news-center-api-1.6.6.0-xt-20181127.070424-1-sources.jar: cn/com/duiba/tuia/news/center/dto/req/UserAccountCenter.java <==
/**
 * Project Name:tuia-youtui-web<br>
 * File Name:UserAccount.java<br>
 * Package Name:com.duiba.tuia.youtui.web.model<br>
 * Date:2017年1月22日下午3:33:46<br>
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.<br>
 */

package cn.com.duiba.tuia.news.center.dto.req;



import java.io.Serializable;
import java.util.Date;

/**
 * 用户相关
 */
public class UserAccountCenter implements Serializable {

    private static final long serialVersionUID = 1L;

    /** The user id. */
    private Long              userId;

    /** 创建时间,注册事件 */
    private Date gmtCreate;

    /** 用户头像 */
    private String image;

    /** 用户昵称 */
    private String nickName;

    /** 用户注册的version */
    private String version;

    /** 当前用户所在的app版本号 */
    private String newVersion;

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public String getNewVersion() {
        return newVersion;
    }

    public void setNewVersion(String newVersion) {
        this.newVersion = newVersion;
    }
}

==> tuia-news-center-api-2.0.0.0-xt-20190403.025840-1-sources.jar: cn/com/duiba/tuia/news/center/dto/req/UserAccountCenter.java <==
/**
 * Project Name:tuia-youtui-web<br>
 * File Name:UserAccount.java<br>
 * Package Name:com.duiba.tuia.youtui.web.model<br>
 * Date:2017年1月22日下午3:33:46<br>
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.<br>
 */

package cn.com.duiba.tuia.news.center.dto.req;



import java.io.Serializable;
import java.util.Date;

/**
 * 用户相关
 */
public class UserAccountCenter implements Serializable {

    private static final long serialVersionUID = 1L;

    /** The user id. */
    private Long              userId;

    /** 创建时间,注册事件 */
    private Date gmtCreate;

    /** 用户头像 */
    private String image;

    /** 用户昵称 */
    private String nickName;

    /** 用户注册的version */
    private String version;

    /** 当前用户所在的app版本号 */
    private String newVersion;

    //任务分组
    private Integer missionGroup =0;

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public String getNewVersion() {
        return newVersion;
    }

    public void setNewVersion(String newVersion) {
        this.newVersion = newVersion;
    }

    public Integer getMissionGroup() {
        return missionGroup;
    }

    public void setMissionGroup(Integer missionGroup) {
        this.missionGroup = missionGroup;
    }
}
